@@ -1,5 +1,22 @@
 # encoding: utf-8
 
+# Nagstamon - Nagios status monitor for your desktop
+# Copyright (C) 2008-2013 Henri Wahl <h.wahl@ifw-dresden.de> et al.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+
 import os
 import platform
 import sys
@@ -15,12 +32,16 @@ class Config(object):
     def __init__(self):
         """
             read config file and set the appropriate attributes
+            supposed to be sensible defaults
         """
-        # supposed to be sensible defaults
-        self.update_interval = 1
+        # move from minute interval to seconds
+        #self.update_interval = 1
+        self.update_interval_seconds = 60
         self.short_display = False
         self.long_display = True
         self.show_grid = True
+        self.default_sort_field = "Status"
+        self.default_sort_order = "Ascending"
         self.filter_all_down_hosts = False
         self.filter_all_unreachable_hosts = False
         self.filter_all_flapping_hosts = False
@@ -32,10 +53,11 @@ class Config(object):
         self.filter_hosts_services_disabled_notifications = False
         self.filter_hosts_services_disabled_checks = False
         self.filter_hosts_services_maintenance = False
-        self.filter_services_on_acknowledged_hosts = False        
+        self.filter_services_on_acknowledged_hosts = False
         self.filter_services_on_down_hosts = False
         self.filter_services_on_hosts_in_maintenance = False
         self.filter_services_on_unreachable_hosts = False
+        self.filter_hosts_in_soft_state = False
         self.filter_services_in_soft_state = False
         self.position_x = 30
         self.position_y = 30
@@ -52,12 +74,13 @@ class Config(object):
         self.check_for_new_version = True
         self.notification = True
         self.notification_flashing = True
+        self.notification_desktop = False
         # because of nonexistent windows systray popup support I'll let it be now
         #self.notification_popup = False
         self.notification_sound = True
         self.notification_sound_repeat = False
         self.notification_default_sound = True
-        self.notification_custom_sound = False      
+        self.notification_custom_sound = False
         self.notification_custom_sound_warning = None
         self.notification_custom_sound_critical = None
         self.notification_custom_sound_down = None
@@ -75,6 +98,9 @@ class Config(object):
         self.re_status_information_enabled = False
         self.re_status_information_pattern = ""
         self.re_status_information_reverse = False
+        self.re_criticality_enabled = False
+        self.re_criticality_pattern = ""
+        self.re_criticality_reverse = False
         self.color_ok_text = self.default_color_ok_text = "#FFFFFF"
         self.color_ok_background = self.default_color_ok_background = "#006400"
         self.color_warning_text = self.default_color_warning_text = "#000000"
@@ -84,14 +110,18 @@ class Config(object):
         self.color_unknown_text = self.default_color_unknown_text = "#000000"
         self.color_unknown_background = self.default_color_unknown_background = "#FFA500"
         self.color_unreachable_text = self.default_color_unreachable_text = "#FFFFFF"
-        self.color_unreachable_background = self.default_color_unreachable_background = "#8B0000"        
+        self.color_unreachable_background = self.default_color_unreachable_background = "#8B0000"
         self.color_down_text = self.default_color_down_text = "#FFFFFF"
         self.color_down_background = self.default_color_down_background = "#000000"
         self.color_error_text = self.default_color_error_text= "#000000"
         self.color_error_background = self.default_color_error_background = "#D3D3D3"
-        self.statusbar_systray = False
+        # going to be obsolete even on Linux
+        #self.statusbar_systray = False
         self.statusbar_floating = True
-        self.icon_in_systray = False  
+        self.icon_in_systray = False
+        self.appindicator = False
+        self.fullscreen = False
+        self.fullscreen_display = 0
         self.systray_popup_offset= 10
         self.defaults_acknowledge_sticky = False
         self.defaults_acknowledge_send_notification = False
@@ -105,7 +135,7 @@ class Config(object):
         self.defaults_downtime_type_fixed = True
         self.defaults_downtime_type_flexible = False
         self.converted_from_single_configfile = False
-       
+
         # the app is unconfigured by default and will stay so if it
         # would not find a config file
         self.unconfigured = True
@@ -119,18 +149,18 @@ class Config(object):
             else:
                 # allow to give a config file
                 self.configdir = sys.argv[1]
-                           
+
         # otherwise if there exits a configfile in current working directory it should be used
         elif os.path.exists(os.getcwd() + os.sep + "nagstamon.config"):
             self.configdir = os.getcwd() + os.sep + "nagstamon.config"
         else:
             # ~/.nagstamon/nagstamon.conf is the user conf file
-            # os.path.expanduser('~') finds out the user HOME dir where 
+            # os.path.expanduser('~') finds out the user HOME dir where
             # nagstamon expects its conf file to be
             self.configdir = os.path.expanduser('~') + os.sep + ".nagstamon"
 
-        self.configfile = self.configdir + os.sep + "nagstamon.conf"      
-            
+        self.configfile = self.configdir + os.sep + "nagstamon.conf"
+
         # make path fit for actual os, normcase for letters and normpath for path
         self.configfile = os.path.normpath(os.path.normcase(self.configfile))
 
@@ -138,14 +168,14 @@ class Config(object):
         # there may be situations where the name gets overwritten by a
         # wrong name so it will be stored here temporarily
         configdir_temp = self.configdir
-                              
+
         # legacy configfile treatment
         legacyconfigfile = self._LoadLegacyConfigFile()
-                
+
         # default settings dicts
         self.servers = dict()
         self.actions = dict()
-        
+
         if os.path.exists(self.configfile):
             # instantiate a Configparser to parse the conf file
             # SF.net bug #3304423 could be fixed with allow_no_value argument which
@@ -155,7 +185,7 @@ class Config(object):
             else:
                 config = ConfigParser.ConfigParser(allow_no_value=True)
             config.read(self.configfile)
-            
+
             # go through all sections of the conf file
             for section in config.sections():
                 # go through all items of each sections (in fact there is only on
@@ -163,28 +193,28 @@ class Config(object):
                 for i in config.items(section):
                     # create a key of every config item with its appropriate value
                     object.__setattr__(self, i[0], i[1])
-                    
+
             # reset self.configdir to temporarily saved value in case it differs from
             # the one read from configfile and so it would fail to save next time
             self.configdir = configdir_temp
-                        
+
             # Servers configuration...
             self.servers = self._LoadServersMultipleConfig()
-            # ... and actions           
+            # ... and actions
             self.actions = self.LoadMultipleConfig("actions", "action", "Action")
-            
+
             # seems like there is a config file so the app is not unconfigured anymore
             self.unconfigured = False
-            
+
             # if configfile has been converted from legacy configfile reset it to the new value
-            self.configfile = self.configdir + os.sep + "nagstamon.conf" 
-            
+            self.configfile = self.configdir + os.sep + "nagstamon.conf"
+
         # flag to be evaluated after gui is initialized and used to show a notice if a legacy config file is used
         # from command line
         self.legacyconfigfile_notice = False
-            
+
         # in case it exists and it has not been used before read legacy config file once
-        if str(self.converted_from_single_configfile) == "False" and not legacyconfigfile == False:            
+        if str(self.converted_from_single_configfile) == "False" and not legacyconfigfile == False:
             # instantiate a Configparser to parse the conf file
             # SF.net bug #3304423 could be fixed with allow_no_value argument which
             # is only available since Python 2.7
@@ -193,18 +223,18 @@ class Config(object):
             else:
                 config = ConfigParser.ConfigParser(allow_no_value=True)
             config.read(legacyconfigfile)
-            
+
             # go through all sections of the conf file
             for section in config.sections():
                 if section.startswith("Server_"):
                     # create server object for every server
                     server_name = dict(config.items(section))["name"]
-                    self.servers[server_name] = Server()                  
-                    
+                    self.servers[server_name] = Server()
+
                     # go through all items of each sections
                     for i in config.items(section):
                             self.servers[server_name].__setattr__(i[0], i[1])
-                        
+
                     # deobfuscate username + password inside a try-except loop
                     # if entries have not been obfuscated yet this action should raise an error
                     # and old values (from nagstamon < 0.9.0) stay and will be converted when next
@@ -215,11 +245,12 @@ class Config(object):
                             self.servers[server_name].password = ""
                         else:
                             self.servers[server_name].password = self.DeObfuscate(self.servers[server_name].password)
+                        self.servers[server_name].autologin_key  = self.DeObfuscate(self.servers[server_name].autologin_key)
                         self.servers[server_name].proxy_username = self.DeObfuscate(self.servers[server_name].proxy_username)
                         self.servers[server_name].proxy_password = self.DeObfuscate(self.servers[server_name].proxy_password)
                     except:
                         pass
-                                       
+
                 elif section == "Nagstamon":
                     # go through all items of each sections (in fact there is only on
                     # section which has to be there to comply to the .INI file standard
@@ -227,33 +258,36 @@ class Config(object):
                         # create a key of every config item with its appropriate value - but please no legacy config file
                         if not i[0] == "configfile":
                             object.__setattr__(self, i[0], i[1])
-                    
+
             # add default actions as examples
             self.actions.update(self._DefaultActions())
-                            
+
             # set flag for config file not being evaluated again
             self.converted_from_single_configfile = True
             # of course Nagstamon is configured then
             self.unconfigured = False
-            
+
             # add config dir in place of legacy config file
-            # in case there is a default install use the default config dir           
+            # in case there is a default install use the default config dir
             if legacyconfigfile == os.path.normpath(os.path.normcase(os.path.expanduser('~') + os.sep + ".nagstamon.conf")):
                 self.configdir = os.path.normpath(os.path.normcase(os.path.expanduser('~') + os.sep + ".nagstamon"))
             else:
                 self.configdir = legacyconfigfile + ".config"
             self.configfile = self.configdir + os.sep + "nagstamon.conf"
-            
+
             # set flag to show legacy command line config file notice
             self.legacyconfigfile_notice = True
 
+            # save converted configuration
+            self.SaveConfig()
+
         # Load actions if Nagstamon is not unconfigured, otherwise load defaults
         if str(self.unconfigured) == "True":
             self.actions = self._DefaultActions()
 
         # do some conversion stuff needed because of config changes and code cleanup
         self._LegacyAdjustments()
-            
+
 
     def _LoadServersMultipleConfig(self):
         """
@@ -263,7 +297,7 @@ class Config(object):
         # deobfuscate username + password inside a try-except loop
         # if entries have not been obfuscated yet this action should raise an error
         # and old values (from nagstamon < 0.9.0) stay and will be converted when next
-        # time saving config        
+        # time saving config
         try:
             for server in servers:
                 servers[server].username = self.DeObfuscate(servers[server].username)
@@ -271,23 +305,26 @@ class Config(object):
                     servers[server].password = ""
                 else:
                     servers[server].password = self.DeObfuscate(servers[server].password)
+                # do only deobfuscating if any autologin_key is set - will be only Centreon
+                if servers[server].__dict__.has_key("autologin_key"):
+                    if len(servers[server].__dict__["autologin_key"]) > 0:
+                        servers[server].autologin_key  = self.DeObfuscate(servers[server].autologin_key)
                 servers[server].proxy_username = self.DeObfuscate(servers[server].proxy_username)
                 servers[server].proxy_password = self.DeObfuscate(servers[server].proxy_password)
         except:
             import traceback
-            traceback.print_exc(file=sys.stdout)   
-        
+            traceback.print_exc(file=sys.stdout)
+
         return servers
-    
-    
+
+
     def _LoadLegacyConfigFile(self):
         """
         load any pre-0.9.9 config file
         """
-        
         # default negative setting
         legacyconfigfile = False
-        
+
         # try to use a given config file - there must be one given
         # if sys.argv is larger than 1
         if len(sys.argv) > 1:
@@ -301,26 +338,26 @@ class Config(object):
             legacyconfigfile = os.getcwd() + os.sep + "nagstamon.conf"
         else:
             # ~/.nagstamon.conf is the user conf file
-            # os.path.expanduser('~') finds out the user HOME dir where 
+            # os.path.expanduser('~') finds out the user HOME dir where
             # nagstamon expects its conf file to be
             legacyconfigfile = os.path.expanduser('~') + os.sep + ".nagstamon.conf"
-            
+
         # make path fit for actual os, normcase for letters and normpath for path
         legacyconfigfile = os.path.normpath(os.path.normcase(legacyconfigfile))
-        
-        if os.path.exists(legacyconfigfile) and os.path.isfile(legacyconfigfile):       
+
+        if os.path.exists(legacyconfigfile) and os.path.isfile(legacyconfigfile):
             return legacyconfigfile
         else:
             return False
-        
-                        
+
+
     def LoadMultipleConfig(self, settingsdir, setting, configobj):
         """
         load generic config into settings dict and return to central config
         """
         # defaults as empty dict in case settings dir/files could not be found
         settings = dict()
-        
+
         try:
             if os.path.exists(self.configdir + os.sep + settingsdir):
                 # dictionary that later gets returned back
@@ -332,10 +369,10 @@ class Config(object):
                         else:
                             config = ConfigParser.ConfigParser(allow_no_value=True)
                         config.read(self.configdir + os.sep + settingsdir + os.sep + f)
-                        
+
                         # create object for every setting
                         name = f.split("_", 1)[1].rpartition(".")[0]
-                        settings[name] = globals()[configobj]()                 
+                        settings[name] = globals()[configobj]()
 
                         # go through all items of the server
                         for i in config.items(setting + "_" + name):
@@ -344,9 +381,9 @@ class Config(object):
         except:
             import traceback
             traceback.print_exc(file=sys.stdout)
-        
+
         return settings
-            
+
 
     def SaveConfig(self, output=None, server=None, debug_queue=None):
         """
@@ -356,7 +393,7 @@ class Config(object):
         try:
             # Make sure .nagstamon is created
             if not os.path.exists(self.configdir):
-                os.mkdir(self.configdir)                
+                os.mkdir(self.configdir)
             # save config file with ConfigParser
             config = ConfigParser.ConfigParser()
             # general section for Nagstamon
@@ -377,11 +414,11 @@ class Config(object):
                     server.Debug(server="", debug="Saving config to " + self.configfile)
                 elif output != None:
                     output.servers.values()[0].Debug(server="", debug="Saving config to " + self.configfile)
-                
+
             # open, save and close config file
             f = open(os.path.normpath(self.configfile), "w")
             config.write(f)
-            f.close()           
+            f.close()
         except:
             # debug
             if str(self.debug_mode) == "True":
@@ -390,11 +427,11 @@ class Config(object):
                 elif output != None:
                     output.servers.values()[0].Debug(server="", debug="Saving config to " + self.configfile)
                 elif debug_queue != None:
-                    debug_string =  " ".join((head + ":",  str(datetime.datetime.now()), "Saving config to " + self.configfile))     
+                    debug_string =  " ".join((head + ":",  str(datetime.datetime.now()), "Saving config to " + self.configfile))
                     # give debug info to debug loop for thread-save log-file writing
                     self.debug_queue.put(debug_string)
-            
-            
+
+
     def SaveMultipleConfig(self, settingsdir, setting):
         """
         saves conf files for settings like actions in extra directories
@@ -413,7 +450,7 @@ class Config(object):
                 for option in self.__dict__[settingsdir][s].__dict__:
                     # obfuscate certain entries in config file - special arrangement for servers
                     if settingsdir == "servers":
-                        if option == "username" or option == "password" or option == "proxy_username" or option == "proxy_password":
+                        if option == "username" or option == "password" or option == "proxy_username" or option == "proxy_password" or option == "autologin_key":
                             value = self.Obfuscate(self.__dict__[settingsdir][s].__dict__[option])
                             if option == "password" \
                                and self.__dict__[settingsdir][s].save_password == "False":
@@ -423,33 +460,33 @@ class Config(object):
                             config.set(setting + "_" + s, option, self.__dict__[settingsdir][s].__dict__[option])
                     else:
                         config.set(setting + "_" + s, option, self.__dict__[settingsdir][s].__dict__[option])
-                        
+
                 # open, save and close config_server file
                 if not os.path.exists(self.configdir + os.sep + settingsdir):
                     os.mkdir(self.configdir + os.sep + settingsdir)
                 f = open(os.path.normpath(self.configdir + os.sep + settingsdir + os.sep + setting + "_" + s + ".conf"), "w")
                 config.write(f)
                 f.close()
-                
+
             # clean up old deleted/renamed config files
             if os.path.exists(self.configdir + os.sep + settingsdir):
                 for f in os.listdir(self.configdir + os.sep + settingsdir):
                     if not f.split(setting + "_")[1].split(".conf")[0] in self.__dict__[settingsdir]:
                         os.unlink(self.configdir + os.sep + settingsdir + os.sep + f)
-            
+
         except:
             import traceback
             traceback.print_exc(file=sys.stdout)
-            
-            
+
+
     def Convert_Conf_to_Multiple_Servers(self):
         """
             if there are settings found which come from older nagstamon version convert them -
             now with multiple servers support these servers have their own settings
-        
+
             DEPRECATED I think, after 2,5 years have passed there should be no version less than 0.8.0 in the wild...
         """
-        
+
         # check if old settings exist
         if self.__dict__.has_key("nagios_url") and \
             self.__dict__.has_key("nagios_cgi_url") and \
@@ -481,17 +518,14 @@ class Config(object):
             self.__dict__.pop("password")
             self.__dict__.pop("use_proxy_yes")
             self.__dict__.pop("use_proxy_no")
-            
-            # save config
-            #self.SaveConfig()
-            
-            
+
+
     def Convert_Conf_to_Custom_Actions(self):
         """
         any nagstamon minor to 0.9.9 will have extra ssh/rdp/vnc settings
         which will be converted to custom actions here
         """
-        
+
         # check if old settings exist
         if self.__dict__.has_key("app_ssh_bin") and \
             self.__dict__.has_key("app_ssh_options") and \
@@ -502,28 +536,13 @@ class Config(object):
             # create actions and fill them with old settings
             self.actions["SSH"] = Action(name="SSH", type="command", description="Converted from pre 0.9.9 Nagstamon.",\
                                          string=self.app_ssh_bin + " " + self.app_ssh_options + " $ADDRESS$")
-            """
-            self.actions["SSH"].type = "command"
-            self.actions["SSH"].name = "SSH"
-            self.actions["SSH"].string = self.app_ssh_bin + " " + self.app_ssh_options + " $ADDRESS$"
-            self.actions["SSH"].description = "Converted from pre 0.9.9 Nagstamon."
-            """
+
             self.actions["RDP"] = Action(name="RDP", type="command", description="Converted from pre 0.9.9 Nagstamon.",\
                                          string=self.app_rdp_bin + " " + self.app_rdp_options + " $ADDRESS$")
-            """
-            self.actions["RDP"].type = "command"
-            self.actions["RDP"].name = "RDP"
-            self.actions["RDP"].string = self.app_rdp_bin + " " + self.app_rdp_options + " $ADDRESS$"
-            self.actions["RDP"].description = "Converted from pre 0.9.9 Nagstamon."
-            """
+
             self.actions["VNC"] = Action(name="VNC", type="command", description="Converted from pre 0.9.9 Nagstamon.",\
                                          string=self.app_vnc_bin + " " + self.app_vnc_options + " $ADDRESS$")
-            """
-            self.actions["VNC"].type = "command"
-            self.actions["VNC"].name = "VNC"
-            self.actions["VNC"].string = self.app_vnc_bin + " " + self.app_vnc_options + " $ADDRESS$"
-            self.actions["VNC"].description = "Converted from pre 0.9.9 Nagstamon."
-            """
+
             # delete old settings from config
             self.__dict__.pop("app_ssh_bin")
             self.__dict__.pop("app_ssh_options")
@@ -531,8 +550,8 @@ class Config(object):
             self.__dict__.pop("app_rdp_options")
             self.__dict__.pop("app_vnc_bin")
             self.__dict__.pop("app_vnc_options")
-            
-        
+
+
     def Obfuscate(self, string, count=5):
         """
             Obfuscate a given string to store passwords etc.
@@ -551,11 +570,11 @@ class Config(object):
         for i in range(count):
             string = zlib.decompress(string)
             string = list(string)
-            string.reverse()   
-            string = "".join(string)    
+            string.reverse()
+            string = "".join(string)
             string = base64.b64decode(string)
         return string
-    
+
 
     def _DefaultActions(self):
         """
@@ -621,11 +640,10 @@ class Config(object):
         defaultactions["Ninja-Configure-Service"] = Action(name="Ninja-Configure-Service", type="browser", filter_target_host=False,\
                                                     description="Configure service in browser.",\
                                                     string="$MONITOR$/index.php/configuration/configure/service/$HOST$?service=$SERVICE$", enabled=False)
-        
+
         return defaultactions
-    
-            
-    
+
+
     def _LegacyAdjustments(self):
         # mere cosmetics but might be more clear for future additions - changing any "nagios"-setting to "monitor"
         for s in self.servers.values():
@@ -637,8 +655,19 @@ class Config(object):
             # to reduce complexity in Centreon there is also only one URL necessary
             if s.type == "Centreon":
                 s.monitor_url = s.monitor_cgi_url
-            
-                
+
+        # switch to update interval in seconds not minutes
+        if self.__dict__.has_key("update_interval"):
+            self.update_interval_seconds = int(self.update_interval) * 60
+            self.__dict__.pop("update_interval")
+
+        # remove support for GNOME2-trayicon-egg-stuff
+        if self.__dict__.has_key("statusbar_systray"):
+            if str(self.statusbar_systray) == "True":
+                self.icon_in_systray = "True"
+            self.__dict__.pop("statusbar_systray")
+
+
     def GetNumberOfEnabledMonitors(self):
         """
         returns the number of enabled monitors - in case all are disabled there is no need to display the popwin
@@ -648,8 +677,8 @@ class Config(object):
         for server in self.servers.values():
             if str(server.enabled) == "True":
                 number += 1
-        return number    
-        
+        return number
+
 
 class Server(object):
     """
@@ -669,14 +698,16 @@ class Server(object):
         self.proxy_address = ""
         self.proxy_username = ""
         self.proxy_password = ""
-        
+        self.use_autologin = False
+        self.autologin_key = ""
+
 
 class Action(object):
     """
     class for custom actions, which whill be thrown into one config dictionary like the servers
     """
-    
-    def __init__(self, **kwds):       
+
+    def __init__(self, **kwds):
         # to be or not to be enabled...
         self.enabled = True
         # one of those: browser, url or command
@@ -689,8 +720,6 @@ class Action(object):
         self.description = "Starts a custom action."
         # might be URL in case of type browser/url and a commandline for commands
         self.string = ""
-        # who did this
-        ###self.author = "Nag Stamon"
         # version - maybe in future this might be more sophisticated
         self.version = "1"
         # kind of Nagios item this action is targeted to - maybe also usable for states
@@ -706,9 +735,12 @@ class Action(object):
         self.re_status_information_enabled = False
         self.re_status_information_pattern = ""
         self.re_status_information_reverse = False
+        self.re_criticality_enabled = False
+        self.re_criticality_pattern = ""
+        self.re_criticality_reverse = False
         # close powin or not, depends on personal preference
         self.close_popwin = True
         self.leave_popwin_open = False
-    
+
         # add and/or all keywords to object
         for k in kwds: self.__dict__[k] = kwds[k]
