@@ -42,62 +42,63 @@ class MultisiteError(Exception):
     def __init__(self, terminate, result):
         self.terminate = terminate
         self.result    = result
-        
-        
+
+
 class LastCheckColumnMultisite(Column):
     """
     because Check_MK has a pretty different date format (much better readable) it has to
     be treaten differently
-    
+
     This is a custom version of LastCheckColumn to be used in list COLUMNS in class Multisite
     """
-    
+
     ATTR_NAME = 'last_check'
-    
+
     @classmethod
     def sort_function(cls, model, iter1, iter2, column):
-        """ Overrides default sorting behaviour """       
+        """ Overrides default sorting behaviour """
         data1, data2 = [model.get_value(x, column) for x in (iter1, iter2)]
-        try:            
+        try:
             first = Actions.MachineSortableDateMultisite(data1)
             second = Actions.MachineSortableDateMultisite(data2)
         except ValueError, err:
             print err
             return cmp(first, second)
         return first - second
-    
-    
+
+
 class DurationColumnMultisite(CustomSortingColumn):
     ATTR_NAME = 'duration'
-    
+
     @classmethod
     def sort_function(cls, model, iter1, iter2, column):
-        """ Overrides default sorting behaviour """       
+        """ Overrides default sorting behaviour """
         data1, data2 = [model.get_value(x, column) for x in (iter1, iter2)]
-        try:            
+        try:
             first = Actions.MachineSortableDateMultisite(data1)
             second = Actions.MachineSortableDateMultisite(data2)
         except ValueError, err:
             print err
             return cmp(first, second)
         return first - second
-    
+
 
 class MultisiteServer(GenericServer):
     """
        special treatment for Check_MK Multisite JSON API
     """
     TYPE = 'Check_MK Multisite'
-    
+
     # URLs for browser shortlinks/buttons on popup window
     BROWSER_URLS= { "monitor": "$MONITOR$",\
                     "hosts": "$MONITOR$/index.py?start_url=view.py?view_name=nagstamon_hosts",\
                     "services": "$MONITOR$/index.py?start_url=view.py?view_name=nagstamon_svc",\
-                    "history": '$MONITOR$/index.py?start_url=view.py?view_name=events'}    
-    
+                    "history": '$MONITOR$/index.py?start_url=view.py?view_name=events'}
+
     # A Monitor CGI URL is not necessary so hide it in settings
-    DISABLED_CONTROLS = ["label_monitor_cgi_url", "input_entry_monitor_cgi_url"]
-    
+    # autologin is used only by Centreon
+    DISABLED_CONTROLS = ["label_monitor_cgi_url", "input_entry_monitor_cgi_url", "input_checkbutton_use_autologin", "label_autologin_key", "input_entry_autologin_key"]
+
     COLUMNS = [
         HostColumn,
         ServiceColumn,
@@ -107,23 +108,27 @@ class MultisiteServer(GenericServer):
         AttemptColumn,
         StatusInformationColumn
     ]
-    
+
+
     def __init__(self, **kwds):
         GenericServer.__init__(self, **kwds)
-        
-        # Prepare all urls needed by nagstamon - 
+
+        # Prepare all urls needed by nagstamon -
         self.urls = {}
         self.statemap = {}
-        
+
         # Entries for monitor default actions in context menu
         self.MENU_ACTIONS = ["Monitor", "Recheck", "Acknowledge", "Downtime"]
-        
+
+        # flag for newer cookie authentication
+        self.CookieAuth = False
+
 
     def init_HTTP(self):
         # Fix eventually missing tailing "/" in url
         if self.monitor_url[-1] != '/':
             self.monitor_url += '/'
-        
+
         # Prepare all urls needed by nagstamon if not yet done
         if len(self.urls) == len(self.statemap):
             self.urls = {
@@ -132,13 +137,13 @@ class MultisiteServer(GenericServer):
                                                    urllib.urlencode({'start_url': 'view.py?view_name=nagstamon_svc'}),
               'human_service':   self.monitor_url + "index.py?%s" %
                                                    urllib.urlencode({'start_url': 'view.py?view_name=service'}),
-    
+
               'api_hosts':       self.monitor_url + "view.py?view_name=nagstamon_hosts&output_format=python",
               'human_hosts':     self.monitor_url + "index.py?%s" %
                                                    urllib.urlencode({'start_url': 'view.py?view_name=nagstamon_hosts'}),
               'human_host':      self.monitor_url + "index.py?%s" %
                                                    urllib.urlencode({'start_url': 'view.py?view_name=hoststatus'}),
-    
+
               'api_reschedule':  self.monitor_url + 'nagios_action.py?action=reschedule',
               'api_host_act':    self.monitor_url + 'view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&output_format=python&view_name=hoststatus',
               'api_service_act': self.monitor_url + 'view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&output_format=python&view_name=service',
@@ -152,11 +157,36 @@ class MultisiteServer(GenericServer):
                 'WARN':    'WARNING',
                 'UNKN':    'UNKNOWN',
                 'PEND':    'PENDING',
-            }            
+            }
+
+        if self.CookieAuth:
+            # get cookie to access Check_MK web interface
+            if len(self.Cookie) == 0:
+                # put all necessary data into url string
+                logindata = urllib.urlencode({"_username":self.get_username(),\
+                                 "_password":self.get_password(),\
+                                 "_login":"1",\
+                                 "_origtarget": "",\
+                                 "filled_in":"login"})
+
+                # get cookie from login page via url retrieving as with other urls
+                try:
+                    # login and get cookie
+                    urlcontent = self.urlopener.open(self.monitor_url + "/login.py", logindata)
+                    urlcontent.close()
+                except:
+                    self.Error(sys.exc_info())
 
         GenericServer.init_HTTP(self)
 
-        
+
+    def init_config(self):
+        """
+        dummy init_config, called at thread start, not really needed here, just omit extra properties
+        """
+        pass
+
+
     def _get_url(self, url):
         result = self.FetchURL(url, 'raw')
         content, error = result.result, result.error
@@ -178,18 +208,19 @@ class MultisiteServer(GenericServer):
             raise MultisiteError(True, Result(result = content,
                                                error = content))
 
+        # looks like cookieauth
+        elif content.startswith('<'):
+            self.CookieAuth = True
+            return ""
+
         return eval(content)
 
-    
+
     def _get_status(self):
         """
-        Get status from Nagios Server
+        Get status from Check_MK Server
         """
         ret = Result()
-        # create Nagios items dictionary with to lists for services and hosts
-        # every list will contain a dictionary for every failed service/host
-        # this dictionary is only temporarily
-        nagitems = {"services":[], "hosts":[]}
 
         # Create URLs for the configured filters
         url_params = ''
@@ -199,7 +230,6 @@ class MultisiteServer(GenericServer):
         url_params += '&is_host_active_checks_enabled=-1&is_service_active_checks_enabled=-1'
         url_params += '&host_scheduled_downtime_depth=-1&is_in_downtime=-1'
 
-        
         try:
             response = []
             try:
@@ -209,7 +239,7 @@ class MultisiteServer(GenericServer):
                     return e.result
 
             for row in response[1:]:
-                host= dict(zip(response[0], row))               
+                host= dict(zip(copy.deepcopy(response[0]), copy.deepcopy(row)))
                 n = {
                     'host':               host['host'],
                     'status':             self.statemap.get(host['host_state'], host['host_state']),
@@ -221,9 +251,6 @@ class MultisiteServer(GenericServer):
                     'address':            host['host_address'],
                 }
 
-                # add dictionary full of information about this host item to nagitems
-                nagitems["hosts"].append(n)
-                # after collection data in nagitems create objects from its informations
                 # host objects contain service objects
                 if not self.new_hosts.has_key(n["host"]):
                     new_host = n["host"]
@@ -243,7 +270,16 @@ class MultisiteServer(GenericServer):
                     if host.has_key('host_acknowledged'):
                         if host['host_acknowledged'] == 'yes':
                             self.new_hosts[new_host].acknowledged = True
-                        
+
+                    # hard/soft state for later filter evaluation
+                    real_attempt, max_attempt = self.new_hosts[new_host].attempt.split("/")
+                    if real_attempt <> max_attempt:
+                        self.new_hosts[new_host].status_type = "soft"
+                    else:
+                        self.new_hosts[new_host].status_type = "hard"
+
+            del response
+
         except:
             self.isChecking = False
             result, error = self.Error(sys.exc_info())
@@ -259,16 +295,14 @@ class MultisiteServer(GenericServer):
             try:
                 response = self._get_url(self.urls['api_services'] + url_params)
             except MultisiteError, e:
-                #print "------------------------------------"
-                #print "%s" % e.result.error
                 if e.terminate:
                     return e.result
                 else:
-                    response = e.result.content
-                    ret = e.result   
-                    
+                    response = copy.deepcopy(e.result.content)
+                    ret = copy.deepcopy(e.result)
+
             for row in response[1:]:
-                service = dict(zip(response[0], row))
+                service = dict(zip(copy.deepcopy(response[0]), copy.deepcopy(row)))
                 n = {
                     'host':               service['host'].encode("utf-8"),
                     'service':            service['service_description'].encode("utf-8"),
@@ -285,10 +319,7 @@ class MultisiteServer(GenericServer):
                     'address':            service['host_address'],
                     'command':            service['svc_check_command'],
                 }
-                
-                # add dictionary full of information about this service item to nagitems - only if service
-                nagitems["services"].append(n)
-                # after collection data in nagitems create objects of its informations
+
                 # host objects contain service objects
                 if not self.new_hosts.has_key(n["host"]):
                     self.new_hosts[n["host"]] = GenericHost()
@@ -308,32 +339,45 @@ class MultisiteServer(GenericServer):
                     self.new_hosts[n["host"]].services[new_service].attempt = n["attempt"]
                     self.new_hosts[n["host"]].services[new_service].status_information = n["status_information"]
                     self.new_hosts[n["host"]].services[new_service].passiveonly = n["passiveonly"]
-                    self.new_hosts[n["host"]].services[new_service].flapping = n["flapping"]                    
+                    self.new_hosts[n["host"]].services[new_service].flapping = n["flapping"]
                     self.new_hosts[n["host"]].services[new_service].site = n["site"]
                     self.new_hosts[n["host"]].services[new_service].address = n["address"]
                     self.new_hosts[n["host"]].services[new_service].command = n["command"]
-                    # transisition to Check_MK 1.1.10p2
+                    # transistion to Check_MK 1.1.10p2
                     if service.has_key('svc_in_downtime'):
                         if service['svc_in_downtime'] == 'yes':
                             self.new_hosts[n["host"]].services[new_service].scheduled_downtime = True
                     if service.has_key('svc_acknowledged'):
                         if service['svc_acknowledged'] == 'yes':
                             self.new_hosts[n["host"]].services[new_service].acknowledged = True
-                    if service.has_key('svc_is_active'):
-                        if service['svc_is_active'] == 'no':
-                            self.new_hosts[n["host"]].services[new_service].passiveonly = True
+                    # the following lead to wrong "passive" P sign in status window
+                    #if service.has_key('svc_is_active'):
+                    #    if service['svc_is_active'] == 'no' and not service['svc_check_command'].startswith('check_mk'):
+                    #        self.new_hosts[n["host"]].services[new_service].passiveonly = True
                     if service.has_key('svc_flapping'):
                         if service['svc_flapping'] == 'yes':
                             self.new_hosts[n["host"]].services[new_service].flapping = True
+
+                    # hard/soft state for later filter evaluation
+                    real_attempt, max_attempt = self.new_hosts[n["host"]].services[new_service].attempt.split("/")
+                    if real_attempt <> max_attempt:
+                        self.new_hosts[n["host"]].services[new_service].status_type = "soft"
+                    else:
+                        self.new_hosts[n["host"]].services[new_service].status_type = "hard"
+
+            del response
+
         except:
             # set checking flag back to False
             self.isChecking = False
             result, error = self.Error(sys.exc_info())
-            return Result(result=result, error=error)
+            return Result(result=copy.deepcopy(result), error=copy.deepcopy(error))
+
+        del url_params
 
         return ret
 
-            
+
     def open_tree_view(self, host, service=""):
         """
         open monitor from treeview context menu
@@ -354,8 +398,8 @@ class MultisiteServer(GenericServer):
         find out ip or hostname of given host to access hosts/devices which do not appear in DNS but
         have their ip saved in Nagios
         """
-        
-        # the fasted method is taking hostname as used in monitor
+
+        # the fastest method is taking hostname as used in monitor
         if str(self.conf.connect_by_host) == "True" or host == "":
             return Result(result=host)
 
@@ -397,9 +441,6 @@ class MultisiteServer(GenericServer):
         result = self.FetchURL(self.urls['api_reschedule'] + '&' + urllib.urlencode({'site': self.hosts[host].site,
                                                                                      'host': host,
                                                                                      'service': service}), giveback='raw')
-        #print result.result
-        # Host: ['OK', 1296825198, 0, 'OK - 127.0.0.1: rta 0,053ms, lost 0%']
-        # Service:  ['OK', 1296827285, 0, 'OK - Agent version 1.1.9i4, execution time 0.1 sec']
 
 
     def get_start_end(self, host):
@@ -451,8 +492,5 @@ class MultisiteServer(GenericServer):
         # acknowledge all services on a host when told to do so
         for s in all_services:
             self._action(self.hosts[host].site, host, s, p)
-            
 
 
-
-        
\ No newline at end of file
